@@ -60,12 +60,12 @@ __use_ini_name__ = "neofile.ini"
 __program_name__ = "PyNeoFile"
 __project__ = __program_name__
 __project_url__ = "https://github.com/GameMaker2k/PyNeoFile"
-__version_info__ = (0, 20, 8, "RC 1", 1)
-__version_date_info__ = (2025, 9, 16, "RC 1", 1)
+__version_info__ = (0, 22, 4, "RC 1", 1)
+__version_date_info__ = (2025, 9, 29, "RC 1", 1)
 __version_date__ = str(__version_date_info__[0]) + "." + str(
     __version_date_info__[1]).zfill(2) + "." + str(__version_date_info__[2]).zfill(2)
 __revision__ = __version_info__[3]
-__revision_id__ = "$Id: 9d99dc742fb061f1486f483f42d795ebfa1f77c8 $"
+__revision_id__ = "$Id: ed81a131e45b3be861589e83174e7a06315ba267 $"
 if(__version_info__[4] is not None):
     __version_date_plusrc__ = __version_date__ + \
         "-" + str(__version_date_info__[4])
@@ -703,7 +703,7 @@ def _parse_global_header(fp, formatspecs, skipchecksum=False):
         raise ValueError(
             "Bad archive header: magic/version mismatch (got {!r}, expected {!r})".format(magicver, expected_magicver)
         )
-    return {'fencoding': fencoding, 'fnumfiles': fnumfiles, 'fostype': fostype,
+    return {'fencoding': fencoding, 'fnumfiles': fnumfiles, 'ffilestart': 0, 'fostype': fostype,
             'fextradata': extras, 'fchecksumtype': checksumtype,
             'ffilelist': [], 'fformatspecs': formatspecs}
 
